<?php

/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019/6/15
 * Time: 11:07
 */
namespace  App\Transformers\Post;

use App\Models\Post;
use App\Models\PostCollect;
use App\Models\PostComment;
use App\Models\PostDislike;
use App\Models\PostLike;
use App\Traits\UserTrait;
use Carbon\Carbon;
use League\Fractal\TransformerAbstract;

class SuggestTransformer extends TransformerAbstract
{
    use UserTrait;
    public function __construct($uid)
    {
        $this->uid = $uid;
    }
    public function transform(Post $post)
    {
        $imgs = [];
        foreach($post->imgs as $img){
            $imgs[] = $img['img'];
        }
        $comment = [];
        $comments = PostComment::where('post_id', $post['id'])->where('parent_id', 0)->orderBy('id', 'desc')->limit(2)->get();
        foreach($comments as $item){
            $replyCount = $item->reply->count();
            $replies = PostComment::where('parent_id', $item->id)->orderBy('id', 'desc')->limit(2)->get();
            $reply = [];
            foreach($replies as $val){
                $reply[] = [
                    'username' => subtext($val->username, 10),
                    'reply_username' => subtext($val->reply_username, 10),
                    'content' => $val->content,
                ];
            }
            $comment[] = [
                'id' => $item->id,
                'username' => subtext($item->username, 10),
                'content' => $item->content,
                'reply_count' => $replyCount,
                'reply' => $reply,
            ];
        }
        $topic = [];
        foreach($post->topic() as $key => $val){
            $topic[] = [
                'id' => $key,
                'name' => $val
            ];
        }
        $isFollow = 0;
        $followStatus = $this->getFollowStatus($this->uid, $post['uid']);
        if($followStatus){
            $isFollow = $followStatus;
        }
        return [
            'show_type' => 'post',
            'id' => $post['id'],
            'type' => $post['type'],
            'created_at' => Carbon::parse($post['created_at'])->diffForHumans(),
            'uid' => $post['uid'],
            'username' => subtext($post['username'], 10),
            'avatar' => $post['avatar'],
            'topic' => $topic,
            'title' => $post['title'],
            'content' => $post['content'],
            'location' => $post['location'],
            'img' => $post['img'],
            'imgs' => $imgs,
            'video' => $post['video'],
            'pv' => $post->data->pv,
            'praise_count' => $post->data->praise_count,
            'comment_count' => $post->data->comment_count,
            'collect_count' => $post->data->collect_count,
            'will_collect_bean' => $post->data->will_collect_bean + 3 * $post->data->pv,
            'is_like' => PostLike::where('post_id', $post['id'])->where('uid', $this->uid)->exists()?1:0,
            'is_dislike' => PostDislike::where('post_id', $post['id'])->where('uid', $this->uid)->exists()?1:0,
            'is_collect' => PostCollect::where('post_id', $post['id'])->where('uid', $this->uid)->exists()?1:0,
            'comment' => $comment,
            'is_follow' => $isFollow,
            'desc_url' => $post['type'] == 'html'?config('customer.app_service_url').'/community/fragment/detail/'.$post['id']:'',
        ];
    }
}